@@ -25,7 +25,7 @@ extensions = [
 project = "oe-python-template"
 author = "Helmut Hoffer von Ankershoffen"
 copyright = f" (c) 2025-{datetime.now(UTC).year}, {author}"  # noqa: A001
-version = "0.2.17"
+version = "0.2.18"
 release = version
 github_username = "helmut-hoffer-von-ankershoffen"
 github_repository = "oe-python-template"
@@ -74,11 +74,11 @@ html_static_path = ["_static"]
 html_logo = "../../logo.png"
 html_theme_options = {
     "announcement": (
-        '<a target="_blank" href="https://github.com/helmut-hoffer-von-ankershoffen/oe-python-template">GitHub</a> - '
-        '<a target="_blank" href="https://pypi.org/project/oe-python-template">PyPI</a> - '
-        '<a target="_blank" href="https://hub.docker.com/r/helmuthva/oe-python-template/tags">Docker</a> - '
+        '<a target="_blank" href="https://github.com/helmut-hoffer-von-ankershoffen/oe-python-template">GitHub</a> - '  # noqa: E501
+        '<a target="_blank" href="https://pypi.org/project/oe-python-template">PyPI</a> - '  # noqa: E501
+        '<a target="_blank" href="https://hub.docker.com/r/helmuthva/oe-python-template/tags">Docker</a> - '  # noqa: E501
         '<a target="_blank" href="https://sonarcloud.io/summary/new_code?id=helmut-hoffer-von-ankershoffen_oe-python-template">SonarQube</a> - '  # noqa: E501
-        '<a target="_blank" href="https://app.codecov.io/gh/helmut-hoffer-von-ankershoffen/oe-python-template">Codecov</a>'
+        '<a target="_blank" href="https://app.codecov.io/gh/helmut-hoffer-von-ankershoffen/oe-python-template">Codecov</a>'  # noqa: E501
     ),
 }
 
